#!/usr/bin/python

def configure_rules(rule):
    """Define the mapping from elements/attribues in UBL to a
    'data collection intent' (DCI)

    First parameter is a substring to match. Second parameter is the DCI.

    The list of possible data collection intents is defined in the next section

    In the event of an overlap, last rule wins.
    """
    rule("ID", "stringinput")
    rule("Code", "stringinput")
    rule("Indicator", "stringinput")
    rule("Name", "stringinput")
    rule("Reason", "stringinput")
    rule("BuildingNumber", "stringinput") # not a bug -- really string
    rule("Mail", "stringinput")
    rule("Telephone", "stringinput")
    rule("Telefax", "stringinput")
    rule("Zone", "stringinput")
    rule("Description", "stringinput")
    rule("Line", "stringinput")
    rule("Terms", "stringinput")
    rule("Country", "stringinput")
    rule("Note", "textarea")
    rule("Date", "dateinput")
    rule("DateTime", "datetimeinput")
    rule("Quantity", "numberinput")
    rule("Numeric", "numberinput")
    rule("GUID", "hidden")
    rule("Amount", "decimalinput")
    rule("@", "hidden")
    rule("/", "group")

def configure_data_collection_intents(intent):
    """A list of the data collection intents (first parameter), and a
    human-readable description of each (second parameter)
    """
    intent("hidden", "not presented to the end user")
    intent("group", "recursive")
    intent("stringinput",  "plain string entry")
    intent("numberinput",  "whole number entry")
    intent("decimalinput", "decimal number entry")
    intent("dateinput",    "date/calendar entry")
    intent("datetimeinput","date and time entry")
    intent("textarea",     "multiline text entry")
    intent("select1-AcknowledgementResponseCode", "code list AcknowledgementResponseCode")
    intent("select1-AllowanceChargeReasonCode",   "code list AllowanceChargeReasonCode")
    intent("select1-ChannelCode",                 "code list ChannelCode")
    intent("select1-ChipCode",                    "code list ChipCode")
    intent("select1-CountryIdentificationCode",   "code list CountryIdentificationCode")
    intent("select1-CurrencyCode",                "code list CurrencyCode")
    intent("select1-DocumentStatusCode",          "code list DocumentStatusCode")
    intent("select1-LatitudeDirectionCode",       "code list LatitudeDirectionCode")
    intent("select1-LineStatusCode",              "code list LineStatusCode")
    intent("select1-LongitudeDirectionCode",      "code list LongitudeDirectionCode")
    intent("select1-OperatorCode",                "code list OperatorCode")
    intent("select1-PaymentMeansCode",            "code list PaymentMeansCode")
    intent("select1-SubstitutionStatusCode",      "code list SubsitutionStatusCode")


def configure_flattened_groups(flatten):
    """A simple list of group names to flatten out by one level.

    (Mainly trivial things like a group-of-one)
    """
    flatten("cac:DeliveryTerms")
    flatten("cac:SalesConditons")
    flatten("cac:LegalTotal")
    flatten("cac:PaymentTerms")
    flatten("cac:AllowanceCharge")
    flatten("cac:OrderReference")
    flatten("cac:OrderedItemIdentification")
    flatten("cac:PartyName")
    flatten("cac:DocumentReference")
    flatten("cac:Contact")
    flatten("cac:SellersItemIdentification")
    flatten("cac:BasePrice")
    flatten("cac:TaxCategory")
    flatten("cac:TaxScheme")
